BetterInteractiveViewerBaseState<T extends BetterInteractiveViewerBase> class abstract

Inheritance
Mixed-in types
Implementers

Properties

animation ↔ Animation<Offset>?
getter/setter pair
childBoundaryRect → Rect?
The _boundaryRect is calculated by adding the boundaryMargin to the size of the child.
no setter
childKey → GlobalKey<State<StatefulWidget>>
final
context → BuildContext
The location in the tree where this widget builds.
no setterinherited
controller ↔ AnimationController
getter/setter pair
currentAxis ↔ Axis?
getter/setter pair
currentRotation ↔ double
getter/setter pair
doubleTabZoomOutScale → double
To determine the scale to zoom out to when double tapping
no setter
doubleTapDetails ↔ TapDownDetails?
Used for getting position of double tap for zoom in and out
getter/setter pair
doubleTapZoomOutBehaviour → DoubleTapZoomOutBehaviour
How to zoom out when double tapping
no setter
gestureType ↔ GestureType?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inNonCoveringZoomHorizontal ↔ bool
getter/setter pair
inNonCoveringZoomVertical ↔ bool
getter/setter pair
mounted → bool
Whether this State object is currently in a tree.
no setterinherited
nonCoveringZoomAlignmentHorizontal → HorizontalNonCoveringZoomAlign
How to align the child on non covering zoom for Horizontal axis
no setter
nonCoveringZoomAlignmentVertical → VerticalNonCoveringZoomAlign
How to align the child on non covering zoom for Vertical axis
no setter
parentKey → GlobalKey<State<StatefulWidget>>
final
realChildSize ↔ Size?
Set this value if the child has a different size than returned by its render box
getter/setter pair
referenceFocalPoint ↔ Offset?
getter/setter pair
rotationStart ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleAnimation ↔ Animation<double>?
getter/setter pair
scaleAnimationFocalPoint ↔ Offset
getter/setter pair
scaleController ↔ AnimationController
getter/setter pair
scaleStart ↔ double?
getter/setter pair
scrollbarController ↔ ScrollbarControllerEncapsulation?
getter/setter pair
setToAfterAnimate ↔ Matrix4?
getter/setter pair
transformationController ↔ TransformationController?
getter/setter pair
transformForRender → Matrix4
The actual transform you should use for rendering
no setter
widget → T
The current configuration.
no setterinherited
widgetViewport → Rect
no setter

Methods

activate() → void
Called when this object is reinserted into the tree after having been removed via deactivate.
inherited
afterAnimate() → void
afterResize({Size? size, bool forceUpdate = true}) → void
Cal this method after resize
afterZoom() → void
Realign the transformation controllers value after a nonCoveringZoom (child is smaller than viewport) to make sure it can be displayed correctly
animateTo(Matrix4 newMatrix, {Duration duration = const Duration(milliseconds: 150), Curve curve = Curves.linear, bool noTranslation = false, dynamic noZoom = false, Offset? focalPoint}) → void
Automatically animates to a new point
build(BuildContext context) → Widget
Build the Widget. Instead of overriding this function, override buildChild so that all gesture detectors can be set up automatically.
override
buildChild(BuildContext context) → Widget
Builds the child.
buildTransformAndScrollbars(BuildContext context, Widget child) → Widget
Gets called from the default build function with the result of buildChild as the child parameter.
createTicker(TickerCallback onTick) → Ticker
Creates a ticker with the given callback.
inherited
deactivate() → void
Called when this object is removed from the tree.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
didChangeDependencies() → void
Called when a dependency of this State object changes.
override
didUpdateWidget(covariant T oldWidget) → void
Called whenever the widget configuration changes.
override
dispose() → void
Called when this object is removed from the tree permanently.
override
gestureIsSupported(GestureType? gestureType, {bool outer = false}) → bool
getGestureType(ScaleUpdateDetails details) → GestureType
Decide which type of gesture this is by comparing the amount of scale and rotation in the gesture, if any. Scale starts at 1 and rotation starts at 0. Pan will have no scale and no rotation because it uses only one finger.
getNonCoveringZoomHorizontalTranslation(double scale) → double
Returns the translation to apply when the child is smaller than the viewport horizontally.
getNonCoveringZoomVerticalTranslation(double scale) → double
Returns the translation to apply when the child is smaller than the viewport vertically.
getScaled({double? scale, Offset? position, Matrix4? matrixZoomedNeedToApplyFocalPointTracking}) → Matrix4
getScrollbarController({required TickerProvider vsync, required TransformScrollbarWidgetInterface controlInterface}) → ScrollbarControllerEncapsulation
handleDoubleTap() → void
initState() → void
Called when this object is inserted into the tree.
override
matrixRotate(Matrix4 matrix, double rotation, Offset focalPoint) → Matrix4
Return a new matrix representing the given matrix after applying the given rotation.
matrixScale(Matrix4 matrix, double scale) → Matrix4
matrixTranslate(Matrix4 matrix, Offset translation) → Matrix4
Return a new matrix representing the given matrix after applying the given translation.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onAnimate() → void
Handle inertia drag animation.
onKey(KeyEvent event) → bool
Used to check if ctrl or shift for scrolling is pressed
onScaleAnimate() → void
Handle inertia scale animation.
onScaleEnd(ScaleEndDetails details, {bool outer = false}) → void
Handle the end of a gesture of _GestureType. All of pan, scale, and rotate are handled with GestureDetector's scale gesture.
onScaleStart(ScaleStartDetails details) → void
Handle the start of a gesture. All of pan, scale, and rotate are handled with GestureDetector's scale gesture.
onScaleUpdate(ScaleUpdateDetails details, {bool inner = false}) → void
Handle an update to an ongoing gesture. All of pan, scale, and rotate are handled with GestureDetector's scale gesture.
reassemble() → void
Called whenever the application is reassembled during debugging, for example during hot reload.
inherited
receivedPointerSignal(PointerSignalEvent event) → void
Handle mousewheel and web trackpad scroll events.
resetAnimation() → void
setScrollbarControllers() → void
Set the scrollbar controllers.
setState(VoidCallback fn) → void
Notify the framework that the internal state of this object has changed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringShort() → String
A brief description of this object, usually just the runtimeType and the hashCode.
inherited
updateTransform() → void
What should happen on transform change.

Operators

operator ==(Object other) → bool
The equality operator.
inherited