CustomTransformScrollbarWidgetInterface class

Implemented types

Constructors

CustomTransformScrollbarWidgetInterface({required Matrix4 fgetTransform(), required void fjumpVertical(double offset), required void fjumpHorizontal(double offset), required void fanimateVertical(double delta, Duration duration, Curve curve), required void fanimateHorizontal(double delta, Duration duration, Curve curve), required Size fgetViewport(), required Size fgetContent(), required BuildContext fcontext()})

Properties

fanimateHorizontal → void Function(double delta, Duration duration, Curve curve)
final
fanimateVertical → void Function(double delta, Duration duration, Curve curve)
final
fcontext BuildContext Function()
final
fgetContent Size Function()
final
fgetTransform Matrix4 Function()
final
fgetViewport Size Function()
final
fjumpHorizontal → void Function(double offset)
final
fjumpVertical → void Function(double offset)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

animateHorizontal(double delta, Duration duration, Curve curve) → void
override
animateVertical(double delta, Duration duration, Curve curve) → void
override
getContent() Size
override
getContext() BuildContext
override
getTransform() Matrix4
override
getViewport() Size
override
jumpHorizontal(double offset) → void
override
jumpVertical(double offset) → void
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited