SimpleTransformScrollbarController class

Inheritance
Implementers

Constructors

SimpleTransformScrollbarController({required Color color, required Animation<double> fadeoutOpacityAnimationVertical, required Animation<double> fadeoutOpacityAnimationHorizontal, Color trackColor = const Color(0x00000000), Color trackBorderColor = const Color(0x00000000), TextDirection? textDirection, double thickness = _kScrollbarThickness, EdgeInsets padding = EdgeInsets.zero, double mainAxisMargin = 0.0, double crossAxisMargin = 0.0, Radius? radius, Radius? trackRadius, OutlinedBorder? shape, double minLength = _kMinThumbExtent, double? minOverscrollLength, bool ignorePointer = false})

Properties

devicePixelRatio double
A changed devicePixelRatio doesn't change anything in thee default implementation. Therefore, it is always 1.0, without checking the actual devicePixelRatio.
no setterinherited
fadeoutOpacityAnimationHorizontal Animation<double>
final
fadeoutOpacityAnimationVertical Animation<double>
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
horizontalScrollbar PublicScrollbarPainter
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verticalScrollbar PublicScrollbarPainter
finalinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
getScrollMetricsH(Matrix4 transform, Size viewport, Size content) ScrollMetrics
inherited
getScrollMetricsV(Matrix4 transform, Size viewport, Size content) ScrollMetrics
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
paint(PaintingContext context, Size viewport, {Offset? origin}) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
toString() String
A string representation of this object.
inherited
update(Matrix4 transform, Size viewport, Size content) → void
inherited
updateAndPaint(PaintingContext context, Matrix4 transform, Size viewport, Size content, {Offset? origin}) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited